#[repr(u8)]pub enum MacCapability {
AlternatePanCoordinator = 0,
DeviceType = 1,
PowerSource = 2,
ReceiverOnWhenIdle = 3,
SecurityCapability = 6,
AllocateAddress = 7,
}Expand description
2.3.2.3.6 - MAC Capability Flags Field
Variants
AlternatePanCoordinator = 0
The alternate PAN coordinator sub-field is one bit in length and shall be set to 1 if this node is capable of becoming a PAN coordinator. Otherwise, the alternative PAN coordinator sub-field shall be set to 0.
DeviceType = 1
The device type sub-field is one bit in length and shall be set to 1 if this node is a full function device (FFD). Otherwise, the device type sub-field shall be set to 0, indicating a reduced function device (RFD).
PowerSource = 2
The power source sub-field is one bit in length and shall be set to 1 if the current power source is mains power. Otherwise, the power source sub-field shall be set to 0. This information is derived from the node current power source field of the node power descriptor.
ReceiverOnWhenIdle = 3
The receiver on when idle sub-field is one bit in length and shall be set to 1 if the device does not disable its receiver to conserve power during idle periods. Otherwise, the receiver on when idle sub-field shall be set to 0.
SecurityCapability = 6
The security capability sub-field is one bit in length and shall be set to 1 if the device is capable of sending and receiving frames secured using the security suite specified in [B1]. Otherwise, the security capability sub-field shall be set to 0.
AllocateAddress = 7
The allocate address sub-field is one bit in length and shall be set to 0 or 1